@@ -97,14 +97,14 @@ class Appliance(EventListener):
         self._notify_listeners()
 
     @property
-    def status(self) -> str:
+    def state(self) -> str:
         return self.__db.get("state", self.STATE_READY)
 
-    @status.setter
-    def status(self, new_status: str):
-        if self.status != new_status:
-            logging.info("new status: " + new_status + " (previous: " + self.status + ")")
-            self.__db.put("state", new_status)
+    @state.setter
+    def state(self, new_state: str):
+        if self.state != new_state:
+            logging.info(self.name + " new state: " + new_state + " (previous: " + self.state + ")")
+            self.__db.put("state", new_state)
 
     @property
     def __previous_run_completed(self) -> bool:
@@ -119,23 +119,23 @@ class Appliance(EventListener):
         operation = self.operation.lower()
 
         if power and operation == 'delayedstart':
-            self.status = self.STATE_DELAYED_STARTED
+            self.state = self.STATE_DELAYED_STARTED
         elif power and operation == 'run':
-            self.status = self.STATE_RUNNING
+            self.state = self.STATE_RUNNING
             self.__previous_run_completed = False
         elif power and operation == 'ready' and self.door.lower() == "closed" and self.__previous_run_completed and self.remote_start_allowed:
-            self.status = self.STATE_STARTABLE
+            self.state = self.STATE_STARTABLE
         elif power and operation == 'finished':
-            self.status = self.STATE_FINISHED
+            self.state = self.STATE_FINISHED
         else:
             if self.door.lower() == 'open' or not power:
                 self.__previous_run_completed = True
             if power and self.door.lower() == 'closed':
-                self.status = self.STATE_READY
+                self.state = self.STATE_READY
             elif power:
-                self.status = self.STATE_FINISHED
+                self.state = self.STATE_FINISHED
             else:
-                self.status = self.OFF
+                self.state = self.OFF
 
     def _notify_listeners(self):
         self.__update_state()
@@ -223,7 +223,6 @@ class Appliance(EventListener):
             logging.info(self.name + " field 'program progress': " + str(self.__program_progress) + " (" + source + ")")
         elif key == 'BSH.Common.Status.LocalControlActive':
             self.__program_local_control_active = change.get('value', None)
-            logging.info(self.name + " field 'local control active': " + str(self.__program_local_control_active) + " (" + source + ")")
         elif key == 'BSH.Common.Status.RemoteControlActive':
             self.program_remote_control_active = change.get('value', False)
             logging.info(self.name + " field 'remote control active': " + str(self.program_remote_control_active) + " (" + source + ")")
@@ -329,7 +328,6 @@ class Dishwasher(Appliance):
         if key == 'BSH.Common.Option.StartInRelative':
             if 'value' in change.keys():
                 self.__program_start_in_relative_sec = change['value']
-                logging.info(self.name + " field 'start in relative': " + str(self.__program_start_in_relative_sec) + " (" + source + ")")
             if 'constraints' in change.keys():
                 constraints = change['constraints']
                 if 'max' in constraints.keys():
@@ -369,33 +367,15 @@ class Dishwasher(Appliance):
         if len(self._program_selected) == 0:
             logging.warning("ignoring start command. No program selected")
 
-        elif self.status == self.STATE_STARTABLE:
+        else:
             remaining_secs_to_wait = int((datetime.fromisoformat(start_date) - datetime.now()).total_seconds())
             if remaining_secs_to_wait < 0:
                 remaining_secs_to_wait = 0
             if remaining_secs_to_wait > self.__program_start_in_relative_sec_max:
                 remaining_secs_to_wait = self.__program_start_in_relative_sec_max
 
-            # update starttime (already started in a delayed manner
-            if self.operation.lower() in ['delayedstart']:
-                try:
-                    data = {
-                        "data": {
-                            "key": "BSH.Common.Option.StartInRelative",
-                            "value": remaining_secs_to_wait,
-                            "unit": "seconds"
-                        }
-                    }
-
-                    self._perform_put("/programs/active/options/BSH.Common.Option.StartInRelative", json.dumps(data, indent=2), max_trials=3)
-                    logging.info(self.name + " update start time: " + self.program_selected +
-                                 " starts in " + print_duration(remaining_secs_to_wait) +
-                                 " (duration " + print_duration(self.program_remaining_time_sec) + ")")
-                except Exception as e:
-                    logging.warning("error occurred by starting " + self.name + " " + str(e))
-
             # start in a delayed manner
-            else:
+            if self.state == self.STATE_STARTABLE:
                 try:
                     data = {
                         "data": {
@@ -414,9 +394,28 @@ class Dishwasher(Appliance):
                                  " (duration " + print_duration(self.program_remaining_time_sec) + ")")
                 except Exception as e:
                     logging.warning("error occurred by starting " + self.name + " " + str(e))
-        else:
-            logging.warning("ignoring start command. " + self.name + " is in state " + self._operation)
-        self._notify_listeners()
+
+            # update start time (already started in a delayed manner)
+            elif self.state == self.STATE_DELAYED_STARTED:
+                try:
+                    data = {
+                        "data": {
+                            "key": "BSH.Common.Option.StartInRelative",
+                            "value": remaining_secs_to_wait,
+                            "unit": "seconds"
+                        }
+                    }
+
+                    self._perform_put("/programs/active/options/BSH.Common.Option.StartInRelative", json.dumps(data, indent=2), max_trials=3)
+                    logging.info(self.name + " update start time: " + self.program_selected +
+                                 " starts in " + print_duration(remaining_secs_to_wait) +
+                                 " (duration " + print_duration(self.program_remaining_time_sec) + ")")
+                except Exception as e:
+                    logging.warning("error occurred by updating start time " + self.name + " " + str(e))
+
+            else:
+                logging.warning("ignoring start command. " + self.name + " is in state " + str(self.state))
+            self._notify_listeners()
 
 
 class FinishInAppliance(Appliance):
@@ -437,7 +436,6 @@ class FinishInAppliance(Appliance):
         elif key == 'BSH.Common.Option.FinishInRelative':  # supported by dryer & washer only
             if 'value' in change.keys():
                 self._program_finish_in_relative_sec = int(change['value'])
-                logging.info(self.name + " field 'finish in relative': " + str(self._program_finish_in_relative_sec) + " (" + source + ")")
             if 'constraints' in change.keys():
                 constraints = change['constraints']
                 if 'max' in constraints.keys():
@@ -459,7 +457,7 @@ class FinishInAppliance(Appliance):
     def read_start_date(self) -> str:
         if self.operation.lower() == 'delayedstart' and self._program_finish_in_relative_sec > 0:
             start_date = datetime.now() + timedelta(seconds=self._program_finish_in_relative_sec) - timedelta(seconds=self.__program_duration_sec())
-            return start_date.strftime("%Y-%m-%d %H:%M")
+            return start_date.strftime("%Y-%m-%dT%H:%M")
         else:
             return ""
 
@@ -473,7 +471,7 @@ class FinishInAppliance(Appliance):
     def __program_duration_sec(self):
         # will update props, if duration is available
         program_fingerprint = self._program_fingerprint()
-        if len(self.program_selected) > 0 and self._program_finish_in_relative_sec > 0 and self.status == self.STATE_READY:
+        if len(self.program_selected) > 0 and self._program_finish_in_relative_sec > 0 and self.state == self.STATE_READY:
             if self._durations.get(program_fingerprint, -1) != self._program_finish_in_relative_sec:   # duration changed?
                 self._durations.put(program_fingerprint, self._program_finish_in_relative_sec)
                 logging.info("duration update for " + program_fingerprint + " with " + str(self._program_finish_in_relative_sec))
@@ -502,26 +500,34 @@ class FinishInAppliance(Appliance):
         self._reload_status_and_settings()
         self._reload_selected_program()
 
+
         # when startable
-        if self.status == self.STATE_STARTABLE:
+        if self.state == self.STATE_STARTABLE:
             program_duration_sec = self.__program_duration_sec()
-            data = {
-                "data": {
-                    "key": self._program_selected,
-                    "options": [{
-                        "key": "BSH.Common.Option.FinishInRelative",
-                        "value": self.__compute_remaining_secs_to_finish(start_date, program_duration_sec),
-                        "unit": "seconds"
-                    }]
-                }
-            }
+            remaining_secs_to_finish = self.__compute_remaining_secs_to_finish(start_date, program_duration_sec)
+
             try:
+                data = {
+                    "data": {
+                        "key": self._program_selected,
+                        "options": [{
+                            "key": "BSH.Common.Option.FinishInRelative",
+                            "value": remaining_secs_to_finish,
+                            "unit": "seconds"
+                        }]
+                    }
+                }
                 self._perform_put("/programs/active", json.dumps(data, indent=2), max_trials=3)
                 logging.info(self.name + " program " + self.program_selected + " starts at " + start_date + " (duration " + str(round(program_duration_sec/(60*60), 1)) + " h)")
             except Exception as e:
                 logging.warning("error occurred by starting " + self.name + " with program " + self.program_selected + " at " + start_date + " (duration: " + str(round(program_duration_sec/(60*60), 1)) + " h) " + str(e))
+
+        # update end time
+        elif self.state == self.STATE_DELAYED_STARTED:
+            logging.warning("updating start time currently not supported")
         else:
-            logging.warning(self.name + " not startable. Ignoring start command.")
+            logging.warning(self.name + " is in state " + str(self.state) + " Ignoring start command.")
+
 
 
 class Washer(FinishInAppliance):
@@ -645,7 +651,7 @@ class Dryer(FinishInAppliance):
     @property
     def program_drying_target_adjustment(self) -> str:
         if len(self.__program_drying_target_adjustment) > 0:
-            return self.__program_drying_target_adjustment[self.__program_drying_target_adjustment.rindex('.') + 1:]
+            return self.__program_drying_.starget_adjustment[self.__program_drying_target_adjustment.rindex('.') + 1:]
         else:
             return ""
 
